<?php
namespace AIOSEO\Plugin\Pro\Meta;

use AIOSEO\Plugin\Common\Meta as CommonMeta;

/**
 * Handles the page title.
 *
 * @since 4.0.0
 */
class Title extends CommonMeta\Title {
	/**
	 * Returns the filtered page title.
	 *
	 * Acts as a helper for getTitle() because we need to encode the title before sending it back to the filter.
	 *
	 * @since 4.0.0
	 *
	 * @param  string $title The original page title.
	 * @return string        The page title.
	 */
	public function filterPageTitle( $title = '' ) {
		$included = new Included();
		return $included->isIncluded() ? parent::filterPageTitle( $title ) : $title;
	}

	/**
	 * Returns the title for the current page.
	 *
	 * @since 4.0.0
	 *
	 * @param  WP_Post|WP_Term $post    The post object (optional).
	 * @param  boolean         $default Whether we want the default value, not the post one.
	 * @return string                   The page title.
	 */
	public function getTitle( $post = null, $default = false ) {
		if ( ! is_category() && ! is_tag() && ! is_tax() ) {
			return parent::getTitle( $post, $default );
		}
		$term = $post ? $post : get_queried_object();
		return $this->getTermTitle( $term, $default );
	}

	/**
	 * Returns the term title.
	 *
	 * @since 4.0.0
	 *
	 * @param  WP_Term $term    The term object.
	 * @param  boolean $default Whether we want the default value, not the post one.
	 * @return string           The term title.
	 */
	public function getTermTitle( $term, $default = false ) {
		$metaData = aioseo()->meta->metaData->getMetaData( $term );

		$title = '';
		if ( ! empty( $metaData->title ) && ! $default ) {
			$title = $this->prepareTitle( $metaData->title );
		}

		$options = aioseo()->options->noConflict();
		if ( ! $title && $options->searchAppearance->dynamic->taxonomies->has( $term->taxonomy ) ) {
			$newTitle = aioseo()->options->searchAppearance->dynamic->taxonomies->{$term->taxonomy}->title;
			$title = $this->prepareTitle( $newTitle, false, $default );
		}
		return $title ? $title : $this->prepareTitle( single_term_title( '', false ), false, $default );
	}
}